
#  Data extractor for PDF documents - pdf-info

  
  
  

Introducing a versatile command line tool and Python library designed to facilitate your PDF document analysis. This tool empowers you to delve into PDF documents seamlessly, offering both command line functionality and a Python library for comprehensive document examination..

  

Extracts important keywords from the docs based on their relevancy.

  

Returns a vector of relevant details!!

  

##  Installation

  
  
  

### Install `pdf-data` using pip

`pip install pdf-data`

  
  
  

###  Use as Python Library

  

You can easily add `pdf-data` to your own Python scripts as library.

  

`import pdf_data`
`result = ob.get_keywords('path/to/my/file.pdf',num_of_keywords=5)`

  
  

##  Maintainers

  

-  [Poorvi Prajapati](https://github.com/Poorvi-P)
